Django Registration Wall — django-registrationwall 0.1 documentation

# Django Registration Wall

Django Registration Wall is a Django mixin application that limits an anonymous user‘s access to content, after which the user is redirected to the login URL. The behavior is modeled after the common paywall scenario.

Fake news articles credit goes to The Onion.

- Package distribution
- Code repository
- Documentation
- Tests

## Install

    $ pip install django-registrationwall

Add to `settings.py`.

    INSTALLED_APPS = [
        # ...
        'regwall',
    ]

Add to one of your `views.py`.

    from django.views.generic import DetailView

    from regwall.mixins import RaiseRegWallMixin

    from .models import Article

    class ArticleDetailView(RaiseRegWallMixin, DetailView):
        model = Article

## Contents

- Install
- Usage
  - Views
  - Template tags
  - Includes
  - Demo
- Settings
  - `REGWALL_LIMIT`
  - `REGWALL_EXPIRE`
  - `REGWALL_SOCIAL`
- Documentation
- Tests

## Indices and tables

- Index
- Module Index
- Search Page